@@ -6,7 +6,9 @@ from .exceptions import TemplateNotFound
 TEMPLATE_DIR = os.path.join(os.path.dirname(__file__),'templates')
 
 environment = jinja2.Environment(
-    loader=jinja2.FileSystemLoader(TEMPLATE_DIR)
+    loader=jinja2.FileSystemLoader(TEMPLATE_DIR),
+    trim_blocks=True,
+    lstrip_blocks=True
     )
 templates = {
     'base':environment.get_template("base.jinja"),
@@ -14,7 +16,10 @@ templates = {
     'gallery_inner':environment.get_template("gallery_inner.jinja"),
     'scroll':environment.get_template('scroll.jinja'),
     'scroll_inner':environment.get_template('scroll_inner.jinja'),
-    'trickle_inner':environment.get_template('trickle_inner.jinja')
+    'trickle_inner':environment.get_template('trickle_inner.jinja'),
+    'toc_inner':environment.get_template('toc_inner.jinja'),
+    'extra':environment.get_template('extra.jinja'),
+    'redirect':environment.get_template('redirect.jinja')
 }
 
 def mdown(src:str)->str:
